@@ -7,6 +7,10 @@
         <source>Error: %1</source>
         <translation>Hata: %1</translation>
     </message>
+    <message>
+        <source>ERROR: Format %1 is not supported for writing, choose another output format. Skipping!</source>
+        <translation>HATA: %1 biçimi yazma için desteklenmiyor, başka bir çıktı biçimi seçin. Atlanıyor!</translation>
+    </message>
 </context>
 <context>
     <name>DialogConversionStatus</name>
@@ -217,6 +221,10 @@ p, li { white-space: pre-wrap; }
         <source>&lt;strong&gt;Russian Translation: &lt;/strong&gt;Stasik Savorovsky - &lt;a href=&quot;mailto:stas_stv@mail.ru&quot;&gt;stas_stv@mail.ru&lt;/a&gt;, Kyrill Detinov - &lt;a href=&quot;mailto:lazy.kent@opensuse.org&quot;&gt;lazy.kent@opensuse.org&lt;/a&gt;, ViktorOn - &lt;a href=&quot;https://github.com/ViktorOn&quot;&gt;ViktorOn&lt;/a&gt;</source>
         <translation>&lt;strong&gt;Rusça çeviri: &lt;/strong&gt;Stasik Savorovsky - &lt;a href=&quot;mailto:stas_stv@mail.ru&quot;&gt;stas_stv@mail.ru&lt;/a&gt;, Kyrill Detinov - &lt;a href=&quot;mailto:lazy.kent@opensuse.org&quot;&gt;lazy.kent@opensuse.org&lt;/a&gt;, ViktorOn - &lt;a href=&quot;https://github.com/ViktorOn&quot;&gt;ViktorOn&lt;/a&gt;</translation>
     </message>
+    <message>
+        <source>Qt Version:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DialogMultipageEditor</name>
@@ -273,6 +281,18 @@ p, li { white-space: pre-wrap; }
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://converseen.fasterland.net/converseen-can-convert-pdf-as-image-files/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;How to enable the PDF conversion?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://converseen.fasterland.net/converseen-can-convert-pdf-as-image-files/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;PDF dönüştürme nasıl etkinleştirilir?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
+    <message>
+        <source>Help</source>
+        <translation>Yardım</translation>
+    </message>
+    <message>
+        <source>Open online help</source>
+        <translation>Çevrim içi yardımı aç</translation>
+    </message>
+    <message>
+        <source>F1</source>
+        <translation>F1</translation>
+    </message>
 </context>
 <context>
     <name>DialogOptions</name>
@@ -391,10 +411,6 @@ p, li { white-space: pre-wrap; }
         <source>WebP General Settings</source>
         <translation>WebP Genel Ayarlar</translation>
     </message>
-    <message>
-        <source>Enable Losseless Compression</source>
-        <translation type="vanished">Kayıpsız Sıkıştırmayı Etkinleştir</translation>
-    </message>
     <message>
         <source>Compression Method:</source>
         <translation>Sıkıştırma Yöntemi:</translation>
@@ -417,7 +433,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Enable Lossless Compression</source>
-        <translation type="unfinished"></translation>
+        <translation>Kayıpsız Sıkıştırmayı Etkinleştir</translation>
     </message>
 </context>
 <context>
@@ -817,10 +833,6 @@ p, li { white-space: pre-wrap; }
         <source>Start with:</source>
         <translation>Şunla başlat:</translation>
     </message>
-    <message>
-        <source>Link aspect with selected image</source>
-        <translation>En boy oranını seçili görüntüyle bağla</translation>
-    </message>
     <message>
         <source>Import PDF file</source>
         <translation>PDF dosyası içe aktar</translation>
@@ -875,6 +887,26 @@ p, li { white-space: pre-wrap; }
         <source>&amp;180°</source>
         <translation>&amp;180°</translation>
     </message>
+    <message>
+        <source>Import directory</source>
+        <translation>İçe aktarma dizini</translation>
+    </message>
+    <message>
+        <source>Online Help</source>
+        <translation>Çevrim İçi Yardım</translation>
+    </message>
+    <message>
+        <source>Open online help</source>
+        <translation>Çevrim içi yardımı aç</translation>
+    </message>
+    <message>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Load Image Sizes&lt;/span&gt;&lt;/p&gt;&lt;p&gt;If &apos;&lt;span style=&quot; font-weight:700;&quot;&gt;px&apos;&lt;/span&gt; is selected, the original image sizes will be loaded into the &lt;span style=&quot; font-weight:700;&quot;&gt;Width/Height&lt;/span&gt; fields. &lt;/p&gt;&lt;p&gt;If &lt;span style=&quot; font-weight:700;&quot;&gt;&apos;%&apos;&lt;/span&gt; is selected, it restores the &lt;span style=&quot; font-weight:700;&quot;&gt;Width/Height&lt;/span&gt; fields to &lt;span style=&quot; font-weight:700;&quot;&gt;100%&lt;/span&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Link Aspect Ratio with Selected Image&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Automatically adjusts the aspect ratio values when you enter a value in the &lt;span style=&quot; font-weight:700;&quot;&gt;Width/Height&lt;/span&gt; fields.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindowImpl</name>
@@ -984,6 +1016,14 @@ Tüm işlemleri iptal etmek için Vazgeç&apos;e tıklayın.</translation>
         <source>Converted</source>
         <translation>Dönüştürüldü</translation>
     </message>
+    <message>
+        <source>Do you want to import subfolders as well?</source>
+        <translation>Alt klasörleri de içe aktarmak istiyor musunuz?</translation>
+    </message>
+    <message>
+        <source>You are going to import %1 directories. Do you want to import subfolders as well?</source>
+        <translation>%1 klasörü içe aktaracaksınız. Alt klasörleri de içe aktarmak istiyor musunuz?</translation>
+    </message>
 </context>
 <context>
     <name>PixTreeWidget</name>
